@@ -4,8 +4,8 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.33'; # VERSION
-our $DATE = '2014-12-05'; # DATE
+our $VERSION = '0.34'; # VERSION
+our $DATE = '2014-12-08'; # DATE
 
 our $_complete_module = sub {
     require Complete::Module;
@@ -13,6 +13,24 @@ our $_complete_module = sub {
 
     my $word = $args{word} // '';
 
+    # convenience: shortcuts (should make this user-configurable in the future).
+    # so if user types 'dzp' it will become 'Dist/Zilla/Plugin/', if she types
+    # 'dzp::' then it will become 'Dist::Zilla::Plugin::'
+    state $shortcuts = {
+        dzp => 'Dist/Zilla/Plugin/',
+        pwp => 'Pod/Weaver/Plugin/',
+        pws => 'Pod/Weaver/Section/',
+    };
+    {
+        my $tmp = lc $word;
+        my $sep;
+        $tmp =~ s!(/|::)\z!! and $sep = $1;
+        if ($shortcuts->{$tmp}) {
+            $word = $shortcuts->{$tmp};
+            if ($sep) { $word =~ s!/!$sep!g }
+        }
+    }
+
     # convenience: allow Foo/Bar.{pm,pod,pmc}
     $word =~ s/\.(pm|pmc|pod)\z//;
 
@@ -72,7 +90,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.33 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-12-05.
+This document describes version 0.34 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-12-08.
 
 =head1 SYNOPSIS
 
@@ -125,7 +143,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.
 
 =head1 BUGS
 
